@@ -3,12 +3,12 @@ context("Test CIDR Operations")
 test_that("asn table ops work",{
 
   asn_table_to_trie(
-    system.file("test", "rib.tst.gz", package="iptools")
+    system.file("test", "rib.tst", package="iptools")
   ) -> asntbl
 
   expect_equal(dim(asntbl), 9994)
 
-  expect_equal(ip_to_asn(asntbl, "5.192.0.1"), 5384)
+  expect_equal(ip_to_asn(asntbl, "5.192.0.1"), "5384")
 
   ips_in_cidrs(
     c("4.3.2.1", "1.2.3.4", "1.20.113.10", "5.190.145.5"),
