@@ -1,4 +1,4 @@
-context("Ensure that ip_in_range and range_boundaries work")
+context("Ensure that ip_in_range, ip_in_any and range_boundaries work")
 
 test_that("ip_in_range works with single values", {
   result <- ip_in_range("172.18.0.0","172.18.0.0/12")
@@ -62,4 +62,4 @@ test_that("range_boundaries error handlers function",{
   expect_that(is.data.frame(result), equals(TRUE))
   expect_that(nrow(result), equals(1))
   expect_that(unname(unlist(result[,1:2])), equals(c("Invalid","Invalid")))
-})
\ No newline at end of file
+})
